-- 
-- Структура таблицы `blog_access`
-- 

DROP TABLE IF EXISTS `blog_access`;
CREATE TABLE `blog_access` (
  `blog_id` int(11) unsigned NOT NULL default '0',
  `user_id` int(11) unsigned default NULL,
  `group_id` int(11) unsigned default NULL,
  `allow_approve_user` enum('0','1') default '1',
  `allow_delete_user` enum('0','1') default '1',
  `allow_edit_post` enum('0','1') default '1',
  `allow_delete_post` enum('0','1') default '1',
  `allow_edit_comment` enum('0','1') default '0',
  `allow_delete_comment` enum('0','1') default '1',
  UNIQUE KEY `blog_user_id` (`blog_id`,`user_id`),
  UNIQUE KEY `blog_group_id` (`blog_id`,`group_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COMMENT='Доступ групп/пользователей к коллективным блогам.';

-- 
-- Структура таблицы `blog_personal_access`
-- 

DROP TABLE IF EXISTS `blog_personal_access`;
CREATE TABLE `blog_personal_access` (
  `group_id` int(11) unsigned default NULL,
  `user_id` int(11) unsigned default NULL,
  `allow_view_post` enum('0','1') default '0',
  `allow_edit_post` enum('0','1') default '1',
  `allow_delete_post` enum('0','1') default '1',
  `allow_edit_comment` enum('0','1') default '0',
  `allow_delete_comment` enum('0','1') default '1',
  UNIQUE KEY `group_id` (`group_id`),
  UNIQUE KEY `user_id` (`user_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COMMENT='Доступ групп/пользователей к личным блогам.';

-- 
-- Структура таблицы `blog_vote`
-- 

DROP TABLE IF EXISTS `blog_vote`;
CREATE TABLE `blog_vote` (
  `voter_id` int(11) unsigned NOT NULL default '0',
  `blog_id` int(11) unsigned NOT NULL default '0',
  UNIQUE KEY `user_blog_id` (`voter_id`,`blog_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COMMENT='Голосование за блоги.';

-- 
-- Структура таблицы `blogs`
-- 

DROP TABLE IF EXISTS `blogs`;
CREATE TABLE `blogs` (
  `blog_id` int(11) unsigned NOT NULL auto_increment,
  `blog_type` enum('0','1','2') NOT NULL default '0',
  `blog_name` varchar(255) NOT NULL,
  `blog_url` varchar(50) NOT NULL,
  `blog_description` varchar(255) NOT NULL default '',
  `blog_add_time` int(11) unsigned default '0',
  `blog_count_users` int(11) unsigned NOT NULL default '0',
  `blog_limit_rating` float(9,3) unsigned NOT NULL default '0.000',
  `blog_rating` float(9,3) unsigned default '0.000',
  `blog_count_vote` int(11) unsigned NOT NULL default '0',
  PRIMARY KEY  (`blog_id`),
  KEY `blog_rating` (`blog_rating`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COMMENT='Тематические блоги.';

-- 
-- Структура таблицы `comment_vote`
-- 

DROP TABLE IF EXISTS `comment_vote`;
CREATE TABLE `comment_vote` (
  `voter_id` int(11) unsigned default '0',
  `comment_id` int(11) unsigned default '0',
  UNIQUE KEY `voter_comment_id` (`voter_id`,`comment_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COMMENT='Голосование за комментарии.';

-- 
-- Структура таблицы `comments`
-- 

DROP TABLE IF EXISTS `comments`;
CREATE TABLE `comments` (
  `comment_id` int(11) unsigned NOT NULL auto_increment,
  `post_id` int(11) unsigned NOT NULL default '0',
  `user_id` int(11) unsigned NOT NULL default '0',
  `comment_time` int(11) unsigned NOT NULL default '0',
  `comment_text` text NOT NULL default '',
  `comment_user_ip` varchar(15) NOT NULL default '0.0.0.0',
  `comment_rating` int(11) default '0',
  PRIMARY KEY  (`comment_id`),
  KEY `post_id` (`post_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COMMENT='Комментарии.';

-- 
-- Структура таблицы `config`
-- 

DROP TABLE IF EXISTS `config`;
CREATE TABLE `config` (
  `config_key` varchar(255) NOT NULL default '',
  `config_value` varchar(255) NOT NULL,
  `config_commentary` varchar(255) NOT NULL,
  PRIMARY KEY  (`config_key`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COMMENT='Настройки системы';

-- 
-- Дамп данных таблицы `config`
-- 

INSERT INTO `config` VALUES ('http_home_url', 'http://my-project', 'Адрес, без закрывающего слеша');
INSERT INTO `config` VALUES ('home_title', 'Wap Blogs Engine', 'Заголовок страниц');
INSERT INTO `config` VALUES ('wap_template', 'HabraLight', '');
INSERT INTO `config` VALUES ('web_template', 'HabraLight', '');
INSERT INTO `config` VALUES ('locale', 'ru_RU', '');
INSERT INTO `config` VALUES ('admin_email', 'email@localhost', 'Email администратора');
INSERT INTO `config` VALUES ('allow_compress', '0', 'Сжатие включено');
INSERT INTO `config` VALUES ('registration_close', '0', 'Регистрация открыта');
INSERT INTO `config` VALUES ('date_adjust', '0', 'Сдвиг времени');
INSERT INTO `config` VALUES ('date_format', 'd rm Y, h:i', '');
INSERT INTO `config` VALUES ('jpeg_quality', '85', 'Качество генерируемых jpeg-изображений');
INSERT INTO `config` VALUES ('flood_time', '30', 'Время антифлуда, сек');
INSERT INTO `config` VALUES ('html_charset', 'utf-8', 'кодировка html-страниц');
INSERT INTO `config` VALUES ('email_charset', 'utf-8', 'кодировка email-писем');
INSERT INTO `config` VALUES ('meta_description', 'wap blogs engine', 'meta description');
INSERT INTO `config` VALUES ('meta_keywords', 'wap, blogs, блоггер, социальность, система', 'meta keywords');
INSERT INTO `config` VALUES ('avatar_width', '150', 'Ширина аватора, px');
INSERT INTO `config` VALUES ('avatar_height', '150', 'Высота аватора, px');
INSERT INTO `config` VALUES ('session_length', '150', 'Длина сессии, сек');
INSERT INTO `config` VALUES ('acl_vote_user_time', '1250786115', '');
INSERT INTO `config` VALUES ('last_vote_tables_clear', '1251533887', '');
INSERT INTO `config` VALUES ('nav_posts', '5', 'Постов на страницу, штук');
INSERT INTO `config` VALUES ('nav_comments', '5', 'Комментариев на страницу, штук');
INSERT INTO `config` VALUES ('length_im', '50', 'Длина IM в профиле, символов');
INSERT INTO `config` VALUES ('length_url', '50', 'Длина URL в профиле, символов');
INSERT INTO `config` VALUES ('length_name', '50', 'Длина имени в профиле, символов');
INSERT INTO `config` VALUES ('length_surname', '150', 'Длина фамилии в профиле, символов');
INSERT INTO `config` VALUES ('length_about', '1500', 'Длина "о себе" в профиле, символов');
INSERT INTO `config` VALUES ('length_interests', '1500', 'Длина интересов в профиле, символов');
INSERT INTO `config` VALUES ('length_phone', '50', 'Длина телефонов в профиле, символов');
INSERT INTO `config` VALUES ('length_wall_message', '500', 'Длина сообщения на стене, символов');
INSERT INTO `config` VALUES ('length_blog_name', '255', 'Длина имени коллективного блога, символов');
INSERT INTO `config` VALUES ('length_blog_description', '255', 'Длина описания коллективного блога, символов');
INSERT INTO `config` VALUES ('length_privmsgs_subject', '255', 'Длина темы приватного сообщения, символов');
INSERT INTO `config` VALUES ('length_privmsgs_message', '2000', 'Длина текста приватного сообщения, символов');
INSERT INTO `config` VALUES ('length_blog_post', '10000', 'Длина поста блога, символов');
INSERT INTO `config` VALUES ('length_blog_post_title', '255', 'Длина заголовка, символов');
INSERT INTO `config` VALUES ('length_blog_comment', '1000', 'Длина комментария, символов');
INSERT INTO `config` VALUES ('quota_blog_tags', '5', 'Квота меток на один посто блога, штук');
INSERT INTO `config` VALUES ('length_blog_tag', '20', 'Длина одной метки, символов');
INSERT INTO `config` VALUES ('answer_template', '%s, %s', 'Шаблон ответа на комментарий / сообщение');
INSERT INTO `config` VALUES ('privmsgs_subject_template', 'Привет, %s!', 'Шаблон темы приваного сообщения');
INSERT INTO `config` VALUES ('privmsgs_quota', '100', 'Квота приваных сообщений, штук');
INSERT INTO `config` VALUES ('acl_can_add_comment', '-10', 'Порог рейтинга при котором юзер может добавлять комментарии');
INSERT INTO `config` VALUES ('acl_can_vote_comment', '-3', 'Порог рейтинга при котором юзер может голосовать за комментарии');
INSERT INTO `config` VALUES ('acl_can_vote_post', '-7', 'Порог рейтинга при котором юзер может голосовать за топик');
INSERT INTO `config` VALUES ('acl_can_vote_blog', '-5', 'Порог рейтинга при котором юзер может голосовать за блог');
INSERT INTO `config` VALUES ('acl_can_vote_user', '-1', 'Порог рейтинга при котором юзер может голосовать за пользователя');
INSERT INTO `config` VALUES ('acl_can_add_post', '-5', '');
INSERT INTO `config` VALUES ('acl_vote_post_time', '86400', '');
INSERT INTO `config` VALUES ('acl_vote_comment_time', '86400', '');
INSERT INTO `config` VALUES ('new_post_time', '86400', '');
INSERT INTO `config` VALUES ('last_vote_user_clear', '1250786189', '');

-- 
-- Структура таблицы `groups`
-- 

DROP TABLE IF EXISTS `groups`;
CREATE TABLE `groups` (
  `group_id` int(11) unsigned NOT NULL auto_increment,
  `group_type` enum('0','1','2') NOT NULL default '0',
  `group_name` varchar(255) NOT NULL default '',
  `group_description` varchar(255) NOT NULL default '',
  `group_add_time` int(11) unsigned NOT NULL default '0',
  `group_count_users` int(11) unsigned NOT NULL default '0',
  PRIMARY KEY  (`group_id`),
  KEY `count_users` (`group_count_users`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COMMENT='Группы';

-- 
-- Структура таблицы `post_vote`
-- 

DROP TABLE IF EXISTS `post_vote`;
CREATE TABLE `post_vote` (
  `voter_id` int(11) unsigned default '0',
  `post_id` int(11) unsigned NOT NULL default '0',
  KEY `user_post_id` (`voter_id`,`post_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COMMENT='Голосование за записи.';

-- 
-- Структура таблицы `posts`
-- 

DROP TABLE IF EXISTS `posts`;
CREATE TABLE `posts` (
  `post_id` int(11) unsigned NOT NULL auto_increment,
  `blog_id` int(11) unsigned NOT NULL default '0',
  `user_id` int(11) unsigned NOT NULL default '0',
  `post_title` varchar(255) NOT NULL default '',
  `post_text` text NOT NULL default '',
  `post_add_time` int(11) unsigned NOT NULL default '0',
  `post_edit_time` int(11) unsigned NOT NULL default '0',
  `post_edit_user_id` int(11) unsigned NOT NULL default '0',
  `privacy_post` enum('0','1','2') default '2',
  `privacy_comment` enum('0','1') default '1',
  `publish_index` enum('0','1') NOT NULL default '0',
  `post_count_comments` int(11) unsigned NOT NULL default '0',
  `post_rating` int(11) default '0',
  `post_count_vote` int(11) unsigned NOT NULL default '0',
  `post_last_comment_id` int(11) unsigned NOT NULL,
  PRIMARY KEY  (`post_id`),
  KEY `blog_id` (`blog_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COMMENT='Записи.';

-- 
-- Структура таблицы `sessions`
-- 

DROP TABLE IF EXISTS `sessions`;
CREATE TABLE `sessions` (
  `ip` varchar(15) NOT NULL default '',
  `user_agent` varchar(100) default NULL,
  `page` varchar(255) NOT NULL default '',
  `user_id` int(11) unsigned NOT NULL default '0',
  `start_time` int(11) unsigned NOT NULL default '0',
  `last_time` int(11) unsigned NOT NULL default '0',
  `count_clicks` int(11) unsigned NOT NULL default '0',
  UNIQUE KEY `ip` (`ip`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COMMENT='Сессии.';

-- 
-- Структура таблицы `tags`
-- 

DROP TABLE IF EXISTS `tags`;
CREATE TABLE `tags` (
  `post_id` int(11) unsigned NOT NULL default '0',
  `post_tag` varchar(50) NOT NULL,
  KEY `post_id_tag` (`post_id`,`post_tag`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COMMENT='Метки.';

-- 
-- Структура таблицы `user_ban`
-- 

DROP TABLE IF EXISTS `user_ban`;
CREATE TABLE `user_ban` (
  `user_id` int(11) unsigned default '0',
  `time` int(11) unsigned NOT NULL default '0',
  `description` varchar(255) NOT NULL,
  `deny_add_post` enum('0','1') default '0',
  `deny_add_comment` enum('0','1') default '0',
  `deny_vote_post` enum('0','1') default '0',
  `deny_vote_blog` enum('0','1') default '0',
  `deny_vote_user` enum('0','1') default '0',
  `deny_vote_comment` enum('0','1') default '0',
  `deny_site` enum('0','1') NOT NULL default '0',
  UNIQUE KEY `user_id` (`user_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COMMENT='Бан.';

-- 
-- Структура таблицы `user_blog`
-- 

DROP TABLE IF EXISTS `user_blog`;
CREATE TABLE `user_blog` (
  `blog_id` int(11) unsigned NOT NULL default '0',
  `user_id` int(11) unsigned NOT NULL default '0',
  UNIQUE KEY `blog_user_id` (`blog_id`,`user_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COMMENT='Читатели блога.';

-- 
-- Структура таблицы `user_blog_entry`
-- 

DROP TABLE IF EXISTS `user_blog_entry`;
CREATE TABLE `user_blog_entry` (
  `blog_id` int(11) unsigned NOT NULL default '0',
  `user_id` int(11) unsigned NOT NULL default '0',
  UNIQUE KEY `blog_user_id` (`blog_id`,`user_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COMMENT='Читатели блога.';

-- 
-- Структура таблицы `user_friend`
-- 

DROP TABLE IF EXISTS `user_friend`;
CREATE TABLE `user_friend` (
  `user_id` int(11) unsigned NOT NULL default '0',
  `friend_user_id` int(11) unsigned NOT NULL default '0',
  UNIQUE KEY `user_friend_id` (`user_id`,`friend_user_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COMMENT='Друзья.';

-- 
-- Структура таблицы `user_friend_entry`
-- 

DROP TABLE IF EXISTS `user_friend_entry`;
CREATE TABLE `user_friend_entry` (
  `user_id` int(11) unsigned NOT NULL default '0',
  `friend_user_id` int(11) unsigned NOT NULL default '0',
  UNIQUE KEY `user_friend_id` (`user_id`,`friend_user_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COMMENT='Заявки дружбы.';

-- 
-- Структура таблицы `user_group`
-- 

DROP TABLE IF EXISTS `user_group`;
CREATE TABLE `user_group` (
  `group_id` int(11) NOT NULL default '0',
  `user_id` int(11) NOT NULL default '0',
  `is_moderator` enum('0','1') NOT NULL default '0',
  UNIQUE KEY `group_user_id` (`group_id`,`user_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COMMENT='Члены групп.';

-- 
-- Структура таблицы `user_vote`
-- 

DROP TABLE IF EXISTS `user_vote`;
CREATE TABLE `user_vote` (
  `voter_id` int(11) unsigned default '0',
  `user_id` int(11) unsigned NOT NULL default '0',
  `time` int(11) unsigned NOT NULL default '0',
  UNIQUE KEY `voter_user_id` (`voter_id`,`user_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COMMENT='Голосование за пользователей.';

-- 
-- Структура таблицы `users`
-- 
DROP TABLE IF EXISTS `users`;
CREATE TABLE `users` (
  `user_id` int(11) NOT NULL auto_increment,
  `user_login` varchar(25) NOT NULL default '',
  `user_password` varchar(32) NOT NULL default '',
  `user_email` varchar(80) NOT NULL default '',
  `user_admin_privilege` enum('0','1') NOT NULL default '0',
  `user_registration` int(11) unsigned NOT NULL default '0',
  `user_last_visit` int(11) unsigned NOT NULL default '0',
  `user_locale` char(5) NOT NULL default 'ru_RU',
  `user_date_adjust` tinyint(2) NOT NULL default '0',
  `user_wap_template` varchar(255) NOT NULL default '',
  `user_web_template` varchar(255) NOT NULL default '',
  `user_skill` float(9,3) unsigned NOT NULL default '0.000',
  `user_rating` float(9,3) NOT NULL default '0.000',
  `user_count_vote` int(11) unsigned NOT NULL default '0',
  `user_unread_privmsgs` int(11) unsigned NOT NULL default '0',
  `user_count_posts` int(11) unsigned NOT NULL default '0', 
  `user_count_comments` int(11) unsigned NOT NULL default '0',
  `user_last_post_time` int(11) unsigned NOT NULL default '0',
  `user_allow_cookies` enum('0','1') NOT NULL default '1',
  `user_allow_images` enum('0','1') NOT NULL default '1',
  `user_allow_translit` enum('0','1') NOT NULL default '0',
  `user_privmsgs_to_email` enum('0','1') NOT NULL  default '0',
  `user_hide_online` enum('0','1') NOT NULL default '0',
  `user_friends_privacy` enum('0','1','2') NOT NULL default '2',
  `user_friendship_privacy` enum('0','1','2') NOT NULL default '2',
  `user_privmsgs_privacy` enum('0','1') NOT NULL default '1',
  `user_wall_privacy` enum('0','1','2') NOT NULL default '2',
  `user_nav_posts` tinyint(2) unsigned NOT NULL default '5',
  `user_nav_comments` tinyint(2) unsigned NOT NULL default '5',
  `user_status` varchar(255) NOT NULL default '',
  `user_sex` enum('m','w') NOT NULL default 'm',
  `user_name` varchar(50) NOT NULL default '',
  `user_surname` varchar(150) NOT NULL default '',
  `user_phone` varchar(50) NOT NULL default '',
  `user_im` varchar(50) NOT NULL default '',
  `user_url` varchar(100) NOT NULL default '',
  `user_interests` text NOT NULL default '', 
  `user_about` text NOT NULL default '',
  PRIMARY KEY  (`user_id`),
  UNIQUE KEY `user_login` (`user_login`),
  UNIQUE KEY `user_email` (`user_email`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COMMENT='Пользователи';